@@ -1038,8 +1038,12 @@ L<Net::Gopher|Net::Gopher>, L<Net::Gopher::Response|Net::Gopher::Response>
 
 Copyright 2003-2004 by William G. Davis.
 
-This module is free software released under the GNU General Public License,
-the full terms of which can be found in the "COPYING" file that comes with
-the distribution.
+This library is free software released under the terms of the GNU Lesser
+General Public License (LGPL), the full terms of which can be found in the
+"COPYING" file that comes with the distribution.
+
+This library is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
+PARTICULAR PURPOSE.
 
 =cut
