@@ -37,6 +37,8 @@ sub launch_item_server
 	return $port;
 }
 
+
+
 sub launch_echo_server
 {
 	my $pid = open(ECHO_SERVER, "$PERL $PATH -e |")
@@ -54,6 +56,8 @@ sub launch_echo_server
 	return $port;
 }
 
+
+
 sub kill_servers
 {
 	return 1 unless ($ITEM_SERVER_PID || $ECHO_SERVER_PID);
@@ -81,4 +85,12 @@ sub kill_servers
 	return 1;
 }
 
+
+
+
+
+BEGIN {
+	$SIG{'__DIE__'} = sub { kill_servers() };
+}
+
 1;
